# encoding : UTF-8 
#
# gsf-pages-ues.rb - Génération des pages décrivant les UEs
#
# Edouard.Thiel@lif.univ-mrs.fr - 14/11/2011
#
# This program is free software under the terms of the
# GNU Lesser General Public License (LGPL) version 2.1.

require './gsf-page-html'
require './gsf-doc-xml'
require './gsf-base-docs'
require './gsf-onglets'
require './gsf-boite'
require './gsf-pied'


class PagesUEs < PageHtml

  # Accesseurs
  #
  attr_accessor :base

  # Initialisation
  #
  def initialize(base)
    super()  # Appelle initialize de la classe mère

    @styles  = [ "style-gsf-15.css"]
    @scripts = []

    @base = base
    @elt_ue = nil
  end


  #----------------------------------------------------------------------------

  # Génère toutes les pages des ues
  #
  def generer_ues()

    if @base == nil || @base.x_ues == nil
      $stderr.puts "** Erreur: generer_site: base XML non définie"
      return
    end

    @base.x_ues.elements.each('liste-ues/ue') do |elt_ue|
      generer_elt_ue(elt_ue)
    end
  end


  # Génère une page d'une ue, désignée par son id
  #
  def generer_ref_ue(ref_ue)

    if @base == nil || @base.x_ues == nil
      $stderr.puts "** Erreur: generer_site_ref_ue: base XML non définie"
      return
    end

    elt_ue = @base.x_ues.get_element('ue', 'id', ref_ue)
    if elt_ue == nil
      $stderr.puts "** Erreur: generer_site_ref_ue: ref '#{ref_ue}' non trouvée"
      return
    end

    generer_elt_ue(elt_ue)
  end


  # Génère une page d'après son élément d'ue XML
  #
  def generer_elt_ue(elt_ue)

    if elt_ue == nil
      $stderr.puts "** Erreur: generer_site_elt_ue: ue indéfinie"
      return
    end
 
    id     = DocXml.get_attr(elt_ue, 'id')
    code   = DocXml.get_text(elt_ue, 'code')
    titre  = DocXml.get_text(elt_ue, 'titre')

    if code == nil
      $stderr.puts "** Erreur: generer_site_elt_ue: code indéfini pour l'ue '#{id}'"
      return
    end

    @elt_ue = elt_ue
    @titre = "UE #{code} - #{titre}"
    dest = "ue-#{code}.html"

    generer_page(dest)
  end


  #------------------------------------------------------------------------------

  # Ecrit le début du corps dans le fichier f
  #
  def ecrire_debut_corps(f)

    f.print "<body>\n\n"

    elt = @base.x_div.get_unique_element('liste-divers/debut-pages')
    f.puts elt.text unless elt == nil
  end


  # Ecrit le corps dans le fichier f
  #
  def ecrire_corps(f)

    return if @elt_ue == nil

    # Les onglets
    gen_html_onglets(f)

    f.puts "\n<div id=\"classeur1\">\n\n"

    # Les boîtes à droite
    gen_html_boites_d(f)

    # Le titre
    titre = DocXml.get_text(@elt_ue, 'titre')
    code  = DocXml.get_text(@elt_ue, 'code')

    f.puts "<h1>L'unité d'enseignement #{code}<br />
    «&nbsp;#{titre}&nbsp;»</h1>\n"

    # La légende
    legende = DocXml.get_text(@elt_ue, 'legende')
    f.puts "<p><i>#{legende}</i></p>\n\n" unless legende == ""

    # Les paragraphes
    liste_par = [ ['objectifs', 'Objectifs'],  
                  ['contenus',  'Contenus' ],
                  ['langage',   'Langages utilisés' ],
                  ['prerequis', 'Prérequis'],
                  ['mcc',       'Modalités de contrôle des connaissances'] ]
    for motcle, titre_par in liste_par do
      valeur = DocXml.get_text(@elt_ue, motcle)
      if ! valeur.strip.empty?
        f.puts "<h2 id=\"section-#{motcle}\">#{titre_par}&nbsp;:</h2>"
        f.puts "<div>\n#{valeur}\n</div>\n\n"
      end
    end

    f.puts "\n</div> <!-- classeur1 -->\n\n"
  end


  # Ecrit la fin du corps dans le fichier f
  #
  def ecrire_fin_corps(f)

    elt = @base.x_div.get_unique_element('liste-divers/fin-pages')
    f.puts elt.text unless elt == nil or elt.text == nil

    f.print "</body>\n\n"
  end


  #------------------------------------------------------------------------------

  # Ecrit des onglets dans le fichier f
  #
  def gen_html_onglets(f)

    elt_debut_ues = @base.x_div.get_unique_element('liste-divers/debut-ues')
    return if elt_debut_ues == nil

    nom_page = DocXml.get_attr(@elt_ue, 'dest')
    onglets = Onglets.new(@base)

    elt_debut_ues.elements.each('onglets') do |elt_onglet|
      onglets.gen_html_onglets(f, elt_onglet, nom_page)
    end
  end


  # Ecrit des boîtes à droite dans le fichier f
  #
  def gen_html_boites_d(f)

    return if @elt_ue == nil

    elt_debut_ues = @base.x_div.get_unique_element('liste-divers/debut-ues')
    return if elt_debut_ues == nil

    boite = Boite.new(@base)

    elt_debut_ues.elements.each('boite-d') do |elt_boite|
      boite.gen_html_boite_d(f, elt_boite, nil, @elt_ue)
    end
  end


  # Ecrit le pied de page dans le fichier f
  #
  def ecrire_pied(f)

    elt_sauv = @base.x_div.get_unique_element('liste-divers/sauvegarde')
    Pied.gen_html_pied(f, elt_sauv)
  end


end  # Fin classe



